@@ -1,5 +1,5 @@
 from interactor.commander.command import DeviceChangeMixin
-from interactor.database.database import Scene, SceneInfo
+from interactor.database.models import Scene, SceneInfo
 from interactor.commander.errors import NoSuchScene
 from interactor.commander import helpers as ihp
 from interactor.commander.store import store
@@ -17,13 +17,25 @@ import asyncio
 import uuid
 
 
+class dictionary_without_none_spec(sb.Spec):
+    def normalise(self, meta, val):
+        val = sb.dictionary_spec().normalise(meta, val)
+        return self.filtered(val)
+
+    def filtered(self, val):
+        if isinstance(val, dict):
+            return {k: self.filtered(v) for k, v in val.items() if v is not None}
+        else:
+            return val
+
+
 @store.command(name="scene_info")
 class SceneInfoCommand(store.Command):
     """
     Retrieve information about scenes in the database
     """
 
-    db_queue = store.injected("db_queue")
+    database = store.injected("database")
 
     uuid = dictobj.NullableField(
         sb.listof(sb.string_spec()), help="Only get information for scene with these uuid"
@@ -34,7 +46,7 @@ class SceneInfoCommand(store.Command):
     )
 
     async def execute(self):
-        def get(db):
+        async def get(session, query):
             info = defaultdict(lambda: {"meta": {}, "scene": []})
 
             fs = []
@@ -43,15 +55,17 @@ class SceneInfoCommand(store.Command):
                 fs.append(Scene.uuid.in_(self.uuid))
                 ifs.append(SceneInfo.uuid.in_(self.uuid))
 
-            for sinfo in db.query(SceneInfo).filter(*ifs):
+            for sinfo in await query.all(SceneInfo, *ifs):
                 info[sinfo.uuid]["meta"] = sinfo.as_dict()
 
-            for scene in db.query(Scene).filter(*fs):
+            for scene in await query.all(Scene, *fs, change=lambda q: q.order_by(Scene.matcher)):
                 # Make sure there is an entry if no SceneInfo for this scene
                 info[scene.uuid]
 
                 if not self.only_meta:
-                    dct = scene.as_dict()
+                    dct = dict(scene.as_dict())
+                    if "uuid" in dct:
+                        del dct["uuid"]
                     info[scene.uuid]["scene"].append(dct)
 
             if self.only_meta:
@@ -60,7 +74,7 @@ class SceneInfoCommand(store.Command):
 
             return dict(info)
 
-        return await self.db_queue.request(get)
+        return await self.database.request(get)
 
 
 @store.command(name="scene_change")
@@ -69,7 +83,7 @@ class SceneChangeCommand(store.Command):
     Set all the options for a scene
     """
 
-    db_queue = store.injected("db_queue")
+    database = store.injected("database")
 
     uuid = dictobj.NullableField(
         sb.string_spec, help="The uuid of the scene to change, if None we create a new scene"
@@ -84,27 +98,27 @@ class SceneChangeCommand(store.Command):
     )
 
     async def execute(self):
-        def make(db):
+        async def make(session, query):
             scene_uuid = self.uuid or str(uuid.uuid4())
 
             if self.scene is not None:
-                for thing in db.queries.get_scenes(uuid=scene_uuid).all():
-                    db.delete(thing)
+                for thing in await query.get_scenes(uuid=scene_uuid):
+                    await session.delete(thing)
 
                 for part in self.scene:
-                    made = db.queries.create_scene(**part(scene_uuid).as_dict())
-                    db.add(made)
+                    made = await query.create_scene(**part(scene_uuid).as_dict())
+                    session.add(made)
 
-            info, _ = db.queries.get_or_create_scene_info(uuid=scene_uuid)
+            info, _ = await query.get_or_create_scene_info(uuid=scene_uuid)
             if self.label is not None:
                 info.label = self.label
             if self.description is not None:
                 info.description = self.description
-            db.add(info)
+            session.add(info)
 
             return scene_uuid
 
-        return await self.db_queue.request(make)
+        return await self.database.request(make)
 
 
 @store.command(name="scene_delete")
@@ -113,22 +127,41 @@ class SceneDeleteCommand(store.Command):
     Delete a scene
     """
 
-    db_queue = store.injected("db_queue")
+    database = store.injected("database")
 
     uuid = dictobj.Field(
-        sb.string_spec, wrapper=sb.required, help="The uuid of the scene to delete"
+        sb.or_spec(sb.boolean(), sb.listof(sb.string_spec())),
+        wrapper=sb.required,
+        help="""
+        Which scenes to delete.
+
+        If this is a string or a list of strings, then those strings are seen as the
+        uuids of the scenes to delete.
+
+        If this option is given as 'true' then all scenes are removed
+        """,
     )
 
     async def execute(self):
-        def delete(db):
-            for thing in db.queries.get_scenes(uuid=self.uuid).all():
-                db.delete(thing)
-            for thing in db.queries.get_scene_infos(uuid=self.uuid).all():
-                db.delete(thing)
+        removed = []
 
-            return {"deleted": True, "uuid": self.uuid}
+        async def delete(session, query):
+            if self.uuid is True:
+                for thing in await query.get_scenes():
+                    removed.append(thing.uuid)
+                    await session.delete(thing)
+                (await query.get_scene_infos()).delete()
+            else:
+                for uu in self.uuid:
+                    removed.append(uu)
+                    for thing in await query.get_scenes(uuid=uu):
+                        await session.delete(thing)
+                    for thing in await query.get_scene_infos(uuid=uu):
+                        await session.delete(thing)
 
-        return await self.db_queue.request(delete)
+            return {"deleted": True, "uuid": list(set(removed))}
+
+        return await self.database.request(delete)
 
 
 @store.command(name="scene_apply")
@@ -137,12 +170,12 @@ class SceneApplyCommand(store.Command, DeviceChangeMixin):
     Apply a scene
     """
 
-    db_queue = store.injected("db_queue")
+    database = store.injected("database")
     request_future = store.injected("request_future")
 
     uuid = dictobj.Field(sb.string_spec, wrapper=sb.required, help="The uuid of the scene to apply")
 
-    overrides = dictobj.Field(sb.dictionary_spec, help="Overrides to the scene")
+    overrides = dictobj.Field(dictionary_without_none_spec, help="Overrides to the scene")
 
     def cap_filter(self, matcher, cap):
         fltr = self.make_filter(matcher)
@@ -155,9 +188,9 @@ class SceneApplyCommand(store.Command, DeviceChangeMixin):
         result = ihp.ResultBuilder()
         self.sender.gatherer.clear_cache()
 
-        def get(db):
+        async def get(session, query):
             info = []
-            for scene in db.queries.get_scenes(uuid=self.uuid).all():
+            for scene in await query.get_scenes(uuid=self.uuid):
                 info.append(scene.as_object())
             if not info:
                 raise NoSuchScene(uuid=self.uuid)
@@ -167,7 +200,7 @@ class SceneApplyCommand(store.Command, DeviceChangeMixin):
             msgs = []
 
             async with hp.TaskHolder(self.request_future, name="SceneApplyCommand") as ts:
-                for scene in await self.db_queue.request(get):
+                for scene in await self.database.request(get):
                     if scene.zones:
                         fltr = self.cap_filter(scene.matcher, "multizone")
                         ts.add(self.apply_zones(fltr, scene, result, msgs))
@@ -176,10 +209,10 @@ class SceneApplyCommand(store.Command, DeviceChangeMixin):
                         ts.add(self.transform(fltr, scene, result, msgs))
 
                     elif scene.chain:
-                        fltr = self.cap_filter(scene.matcher, "chain")
+                        fltr = self.cap_filter(scene.matcher, "matrix")
                         ts.add(self.apply_chain(fltr, scene, result, msgs))
 
-                        fltr = self.cap_filter(scene.matcher, "not_chain")
+                        fltr = self.cap_filter(scene.matcher, "not_matrix")
                         ts.add(self.transform(fltr, scene, result, msgs))
 
                     else:
@@ -231,7 +264,6 @@ class SceneCaptureCommand(store.Command, DeviceChangeMixin):
     """
 
     path = store.injected("path")
-    db_queue = store.injected("db_queue")
     executor = store.injected("executor")
 
     uuid = dictobj.NullableField(
@@ -269,10 +301,10 @@ class SceneCaptureCommand(store.Command, DeviceChangeMixin):
             if device.cap.has_multizone:
                 part = parts[0]
                 state["zones"] = [list(color) for i, color in zip(range(part.width), part.colors)]
-            elif device.cap.has_chain:
+            elif device.cap.has_matrix:
                 chain = []
                 for part in parts:
-                    chain.append([list(color) for color in part.colors])
+                    chain.append([list(color) for color in part.colors[: part.width * part.height]])
                 state["chain"] = chain
             else:
                 color = parts[0].colors[0]
@@ -282,27 +314,31 @@ class SceneCaptureCommand(store.Command, DeviceChangeMixin):
 
             scene.append(state)
 
-        result.result["results"] = {"scene": scene}
+        result.result["results"] = {"scene": sorted(scene, key=lambda s: s["matcher"]["serial"])}
 
         if self.just_return:
             return result.as_dict()
 
         args = {
             "uuid": self.uuid,
+            "scene": scene,
             "label": self.label,
             "description": self.description,
         }
 
-        result.result["results"]["meta"] = dict(args)
-        args["scene"] = scene
-
         try:
             uuid = await self.executor.execute(self.path, {"command": "scene_change", "args": args})
         except asyncio.CancelledError:
             raise
         except Exception as error:
             result.error(error)
-        else:
-            result.result["results"]["meta"]["uuid"] = uuid
+            return result.as_dict()
 
-        return result.as_dict()
+        info = await self.executor.execute(
+            self.path, {"command": "scene_info", "args": {"uuid": uuid}}
+        )
+
+        if uuid in info:
+            return info[uuid]
+        else:
+            return info
