@@ -18,6 +18,11 @@ log = logging.getLogger("interactor.server")
 REQUEST_IDENTIFIER_HEADER = "X-Request-ID"
 
 
+class StatusHandler(tornado.web.RequestHandler):
+    def get(self):
+        self.write("working")
+
+
 class Commander(Commander):
     def peek_valid_request(self, meta, command, path, body):
         request = meta.everything["request_handler"].request
@@ -114,6 +119,10 @@ class Server(Server):
         self.wsconnections = {}
 
     async def wait_for_end(self):
+        # Wait till the server has successfully started to begin any zeroconf registration
+        await self.server_options.zeroconf.start(
+            self.tasks, self.host, self.port, self.sender, self.finder
+        )
         await hp.wait_for_all_futures(self.server_end_future, name="Server::wait_for_end")
 
     def make_application(self, *args, **kwargs):
@@ -134,6 +143,7 @@ class Server(Server):
                     "wsconnections": self.wsconnections,
                 },
             ),
+            ("/v1/lifx/status", StatusHandler),
         ]
 
     async def setup(self, server_options, *, tasks, sender, cleaners, animation_options=None):
@@ -170,6 +180,7 @@ class Server(Server):
             tasks=self.tasks,
             sender=self.sender,
             finder=self.finder,
+            zeroconf=self.server_options.zeroconf,
             database=self.database,
             animations=self.animations,
             final_future=self.final_future,
@@ -178,6 +189,7 @@ class Server(Server):
 
     async def cleanup(self):
         self.tasks.add(self.animations.stop())
+        self.tasks.add(self.server_options.zeroconf.finish())
         await hp.wait_for_all_futures(
             *self.wsconnections.values(), name="Server::cleanup[wait_for_wsconnections]"
         )
